==> haskell-persistent-qq-2.12.0.7-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-qq
version:              2.12.0.7
visibility:           public
id:                   persistent-qq-2.12.0.7-56Q0oJeO4Dz4LSj9f2d4E6
key:                  persistent-qq-2.12.0.7-56Q0oJeO4Dz4LSj9f2d4E6
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  c6ba3eaa768eb5f454a1933f6dc56a4a
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.7-56Q0oJeO4Dz4LSj9f2d4E6
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-B9zZU77YEHg2xcsLuIS94l
    mtl-2.2.2 persistent-2.14.5.2-JZS0GlevepsLmstVrsXVsb
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-qq-2.12.0.7-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-qq
version:              2.12.0.7
visibility:           public
id:                   persistent-qq-2.12.0.7-2qO267V7A3QF8TfPS6zPEq
key:                  persistent-qq-2.12.0.7-2qO267V7A3QF8TfPS6zPEq
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
homepage:             https://github.com/yesodweb/persistent#readme
synopsis:             Provides a quasi-quoter for raw SQL for persistent
description:
    Please see README and API docs at <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  13de508186013df9d408789d64742211
exposed:              True
exposed-modules:      Database.Persist.Sql.Raw.QQ
hidden-modules:       Paths_persistent_qq
import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-qq-2.12.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-qq
hs-libraries:         HSpersistent-qq-2.12.0.7-2qO267V7A3QF8TfPS6zPEq
depends:
    base-4.17.2.1 haskell-src-meta-0.8.15-8JHVqMNfqJk4T3jAnKJCkj
    mtl-2.2.2 persistent-2.14.5.2-EmCOn013C8VJsZaWFIHLVX
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-persistent-qq/html/persistent-qq.haddock

haddock-html:         /usr/share/doc/haskell-persistent-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
